@@ -108,6 +108,7 @@ seqsplot <- function(seqdata, group = NULL, main = NULL, cpal = NULL,
               message(" [!] too many groups (> 8), no automatic color palette assignation")
               NULL
             }
+       cpal <- cpal.grp
      }
      else {
       cpal.grp <- cpal
@@ -126,25 +127,6 @@ seqsplot <- function(seqdata, group = NULL, main = NULL, cpal = NULL,
      group <- TraMineR:::group(group)
      levels.num <- nlevels(group)
 
-     if (is.null(cpal)){
-       ## We use Dark2 from brewer.pal, which has 8 colors
-       ## Moreover, min n for brewer.pal is 3
-       cpal <-
-            if (levels.num < 2) {
-              brewer.pal(3, "Dark2")[3]
-            } else if (levels.num == 2) {
-              brewer.pal(3, "Dark2")[-3]
-            } else if (levels.num < 9) {
-              brewer.pal(levels.num, "Dark2")
-            } else {
-              message(" [!] too many groups (> 8), no automatic color palette assignation")
-              NULL
-            }
-     }
-     if (is.null(ltext)){
-        if (levels.num >0) ltext.grp <- levels(group.ori)
-        else ltext.grp <- "All cases"
-     }
    }
 
 
@@ -232,12 +214,15 @@ seqsplot <- function(seqdata, group = NULL, main = NULL, cpal = NULL,
       if (per.state) {
         olist[["state"]] <- as.character(group[np])
         olist[["groups"]] <- group.ori
-        #if (levels.num > 1)
-        #  olist[["groups"]] <- group.ori
-        #else {
-        #  olist[["groups"]] <- NULL
-          ##olist[["per.state"]] <- FALSE
-        #}
+        ## Here, we check whether all groups have the considered state
+        lcpal <- vector()
+        for (g in 1:levels.num){
+          lcpal[g] <- (as.character(group[np]) %in% as.character(seqstatl(subdata[group.ori==levels(group.ori)[g],])))
+        }
+        plist[["cpal"]] <- cpal[lcpal]
+      }
+      else { # per.state=FALSE
+        plist[["cpal"]] <- cpal[alphabet(subdata)[sel.states] %in% seqstatl(subdata)]
       }
     }
 		else
